@@ -280,11 +280,9 @@ EXCLUDE = (
     "lib/glcomp/glcompset.c",
     "lib/glcomp/glcompset.h",
     "lib/glcomp/glcomptextpng.c",
-    "lib/glcomp/glcomptextpng.h",
     "lib/glcomp/glcomptexture.c",
     "lib/glcomp/glcomptexture.h",
     "lib/glcomp/glpangofont.c",
-    "lib/glcomp/glpangofont.h",
     "lib/glcomp/glutils.c",
     "lib/glcomp/glutils.h",
     "lib/gvc/gvc.c",
@@ -593,7 +591,7 @@ EXCLUDE = (
     "tclpkg/tcldot/tcldot-nodecmd.c",
     "tclpkg/tcldot/tcldot-util.c",
     "tclpkg/tcldot/tcldot.h",
-    "tclpkg/tcldot/tcldot_builtins.c",
+    "tclpkg/tcldot/tcldot_builtins.cpp",
     "tclpkg/tclpathplan/find_ints.c",
     "tclpkg/tclpathplan/intersect.c",
     "tclpkg/tclpathplan/makecw.c",
