@@ -10,19 +10,7 @@ python3 -m pip install --requirement requirements.txt
 
 export PATH=$PATH:/c/Git/cmd
 
-if [ "${build_system}" = "cmake" ]; then
-    DIR_REL="$(echo build/_CPack_Packages/win64/NSIS/Graphviz-*-win[36][24])"
-else
-    echo "Error: ${build_system} is not yet supported" >&2
-    exit 1
-fi
-
-# we need the absolete path since pytest cd somewhere else
-
-# we need the Win32 value of the physical directory since somehow the
-# symbolic one is not understood in the -L flag. In the -I flag the
-# path gets mysteriously translated and works anyway
-DIR_WABS="C:/Graphviz"
+# we need the absolute path since pytest cd somewhere else
 
 # we need the logical value of the directory for the PATH
 DIR_LABS="/c/Graphviz"
@@ -39,4 +27,4 @@ export PATH="${PATH}:$DIR_LABS/bin"
 python gen_version.py --output GRAPHVIZ_VERSION
 export GV_VERSION=$( cat GRAPHVIZ_VERSION )
 
-python3 -m pytest --verbose ci/tests.py tests
+python3 -m pytest --strict-markers --verbose --verbose ci/tests.py tests
