@@ -14,15 +14,15 @@
 
 #include "config.h"
 #include "../tools/openFile.h"
-#include <cgraph/alloc.h>
 #include <cgraph/cgraph.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/exit.h>
 #include <cgraph/ingraphs.h>
 #include <cgraph/startswith.h>
-#include <cgraph/unreachable.h>
 #include <common/pointset.h>
 #include <getopt.h>
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/unreachable.h>
 
 #include <sparse/general.h>
 #include <sparse/SparseMatrix.h>
@@ -36,6 +36,7 @@
 
 static char *fname;
 static FILE *outfile;
+static char **Files;
 
 static void usage (char* cmd, int eval){
   fprintf(stderr, "Usage: %s <options> gv file with 2D coordinates.\n", cmd);
@@ -80,7 +81,7 @@ checkG (Agraph_t* g)
 
 static void init(int argc, char *argv[], double *angle, double *accuracy,
                  int *check_edges_with_same_endpoint, int *seed,
-                 char **color_scheme, int *lightness) {
+                 const char **color_scheme, int *lightness) {
 
   char* cmd = argv[0];
   outfile = NULL;
@@ -170,7 +171,7 @@ static void init(int argc, char *argv[], double *angle, double *accuracy,
       if (outfile != NULL) {
         fclose(outfile);
       }
-      outfile = openFile(CmdName, arg, "w");
+      outfile = openFile(cmd, arg, "w");
       break;
 
     case 'v':
@@ -198,6 +199,7 @@ static void init(int argc, char *argv[], double *angle, double *accuracy,
                 "--color_scheme option must be a known color scheme.\n");
         usage(cmd, EXIT_FAILURE);
       }
+      *color_scheme = arg;
       break;
 
     case OPT_LIGHTNESS: {
@@ -240,7 +242,7 @@ static void init(int argc, char *argv[], double *angle, double *accuracy,
 
 static int clarify(Agraph_t *g, double angle, double accuracy,
                    int check_edges_with_same_endpoint, int seed,
-                   char *color_scheme, int *lightness) {
+                   const char *color_scheme, int *lightness) {
 
   if (checkG(g)) {
     agerrorf("Graph %s contains loops or multiedges\n", agnameof(g));
@@ -260,7 +262,7 @@ int main(int argc, char *argv[])
   double accuracy;
   double angle;
   int check_edges_with_same_endpoint, seed;
-  char *color_scheme = NULL;
+  const char *color_scheme = NULL;
   int lightness[] = {0, 70};
   Agraph_t *g;
   Agraph_t *prev = NULL;
