@@ -14,7 +14,6 @@ XDOT DRAWING FUNCTIONS, maybe need to move them somewhere else
 		for now keep them at the bottom
 */
 #include "draw.h"
-#include <cgraph/unreachable.h>
 #include <common/colorprocs.h>
 #include <common/types.h>
 #include <common/utils.h>
@@ -23,6 +22,7 @@ XDOT DRAWING FUNCTIONS, maybe need to move them somewhere else
 #include <math.h>
 #include <stdbool.h>
 #include <stdlib.h>
+#include <util/unreachable.h>
 
 #include <xdot/xdot.h>
 #include "viewport.h"
@@ -138,8 +138,7 @@ static void DrawBeziers(sdot_op* o, int param)
     }
 }
 
-//Draws an ellpise made out of points.
-//void DrawEllipse(xdot_point* xpoint,GLfloat xradius, GLfloat yradius,int filled)
+//Draws an ellipse made out of points.
 static void DrawEllipse(sdot_op*  o, int param)
 {
     int i = 0;
@@ -238,8 +237,7 @@ static void DrawPolyline(sdot_op* o, int param)
     glEnd();
 }
 
-static glCompColor GetglCompColor(char *color)
-{
+static glCompColor GetglCompColor(const char *color) {
     gvcolor_t cl;
     glCompColor c;
     if (color != NULL) {
@@ -305,7 +303,7 @@ static void InsertImage(sdot_op * o, int param)
 	}
 	i->width = o->op.u.image.pos.w;
 	i->height = o->op.u.image.pos.h;
-	i->common.functions.draw(i);
+	i->base.common.functions.draw(i);
     }
 }
 
