@@ -21,13 +21,13 @@
 #include <assert.h>
 #include "gvprpipe.h"
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/startswith.h>
-#include <cgraph/strcasecmp.h>
 #include <cgraph/strview.h>
-#include <cgraph/unreachable.h>
 #include <stdint.h>
 #include <string.h>
+#include <util/alloc.h>
+#include <util/strcasecmp.h>
+#include <util/unreachable.h>
 
 static int sel_node;
 static int sel_edge;
@@ -107,7 +107,6 @@ static void reset_attr_list_widgets(attr_list * l)
 static attr_list *attr_list_new(bool with_widgets) {
     int id;
     attr_list *l = gv_alloc(sizeof(attr_list));
-    l->with_widgets = with_widgets;
     /*create filter widgets */
 
     if (with_widgets) {
@@ -207,6 +206,7 @@ static void set_attr_object_type(const char *str, int *t) {
 }
 
 static attr_t *binarySearch(attr_list *l, const char *searchKey) {
+  attrs_sync(&l->attributes);
   attr_t **attrp = bsearch(searchKey, attrs_front(&l->attributes),
                            attrs_size(&l->attributes), sizeof(attr_t*),
                            attr_compare_core);
@@ -355,16 +355,6 @@ _BB void on_txtAttr_changed(GtkWidget *widget, void *user_data) {
   filter_attributes(gtk_entry_get_text((GtkEntry*)widget), view->Topview);
 }
 
-static void set_refresh_filters(ViewInfo * v, char *name)
-{
-    if (strcasecmp(name, "pos") == 0)
-	v->refresh.pos = 1;
-    if (strcasecmp(name, "color") == 0)
-	v->refresh.color = 1;
-    if (strcasecmp(name, "selected") == 0)
-	v->refresh.selection = 1;
-}
-
 static void doApply(void)
 {
     char *attr_name;
@@ -419,7 +409,6 @@ static void doApply(void)
 	fprintf(stderr,
 	    "on_attrApplyBtn_clicked: unknown object kind %d\n",
 	    objKind);
-    set_refresh_filters(view, attr_name);
 }
 
 _BB void on_attrApplyBtn_clicked(GtkWidget *widget, void *user_data) {
