@@ -22,6 +22,7 @@
 #include "selectionfuncs.h"
 #include <stdbool.h>
 #include <stdint.h>
+#include <stdlib.h>
 #include "frmobjectui.h"
 
 static glCompPanel *sel = NULL;
@@ -81,7 +82,7 @@ static void menu_switch_to_fisheye(glCompObj *obj, float x, float y,
 	view->Topview->fisheyeParams.active = 1;
 	glCompButtonShow(toNormal);
 	glCompButtonHide(toFisheye);
-	imgFisheye->common.visible = 1;
+	imgFisheye->base.common.visible = 1;
 
 
     } else {
@@ -89,7 +90,7 @@ static void menu_switch_to_fisheye(glCompObj *obj, float x, float y,
 	g_timer_stop(view->timer);
 	glCompButtonHide(toNormal);
 	glCompButtonShow(toFisheye);
-	imgFisheye->common.visible = 0;
+	imgFisheye->base.common.visible = 0;
 
 
     }
@@ -128,15 +129,14 @@ void switch2D3D(glCompObj *obj, float x, float y, glMouseButtonType t) {
 	    }
 	    glCompButtonShow(to2DBtn);
 	    glCompButtonHide(to3DBtn);
-	    img3D->common.visible = 1;
+	    img3D->base.common.visible = 1;
 	} else {		/*switch to 2d */
 
 	    view->active_camera = SIZE_MAX; // set to camera
 	    glCompButtonShow(to3DBtn);
 	    glCompButtonHide(to2DBtn);
-	    panBtn->common.callbacks.click((glCompObj*)panBtn, 0.0f, 0.0f,
-					   (glMouseButtonType) 0);
-	    img3D->common.visible = 0;
+	    panBtn->base.common.callbacks.click(&panBtn->base, 0.0f, 0.0f, 0);
+	    img3D->base.common.visible = 0;
 
 
 	}
@@ -150,9 +150,8 @@ static void CBglCompMouseUp(glCompObj *obj, float x, float y, glMouseButtonType
     (void)y;
     (void)t;
 
-    sel->common.visible = 0;
-    sel->common.pos.x = -5000;
-
+    sel->base.common.visible = 0;
+    sel->base.common.pos.x = -5000;
 }
 
 static void CBglCompMouseRightClick(glCompObj *obj, float x, float y,
@@ -182,15 +181,14 @@ static void glCompMouseMove(glCompObj *obj, float x, float y) {
 
     glCompMouse *m = &((glCompSet *) obj)->mouse;
 
-    sel->common.visible = 1;
-
+    sel->base.common.visible = 1;
 
     if ((m->down) && (m->t == glMouseRightButton)) 
     {
-	sel->common.pos.x = m->pos.x - m->dragX;
-	sel->common.pos.y = m->pos.y - m->dragY;
-	sel->common.width = m->dragX;
-	sel->common.height = m->dragY;
+	sel->base.common.pos.x = m->pos.x - m->dragX;
+	sel->base.common.pos.y = m->pos.y - m->dragY;
+	sel->base.common.width = m->dragX;
+	sel->base.common.height = m->dragY;
 	glexpose();
     }
 }
@@ -222,62 +220,81 @@ glCompSet *glcreate_gl_topview_menu(void)
     glCompButton *b = NULL;
     glCompImage *i = NULL;
     glCompColor c;
-    s->common.callbacks.click = CBglCompMouseRightClick;
+    s->base.common.callbacks.click = CBglCompMouseRightClick;
 
     p = glCompPanelNew(s, 25, 25, 45, 47);
-    p->common.align = glAlignLeft;
-    p->common.data = 0;
+    p->base.common.align = glAlignLeft;
+    p->base.common.data = 0;
 
     /*pan */
-    b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
-    glCompButtonAddPngGlyph(b, smyrnaPath("pan.png"));
-    b->common.callbacks.click = menu_click_pan;
+    b = glCompButtonNew(p, 1, y, 42, 42, "");
+    {
+      char *pan = smyrnaPath("pan.png");
+      glCompButtonAddPngGlyph(b, pan);
+      free(pan);
+    }
+    b->base.common.callbacks.click = menu_click_pan;
     panBtn = b;
 
     y = y + off;
 
     /*switch to fisheye */
-    b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
-    glCompButtonAddPngGlyph(b, smyrnaPath("fisheye.png"));
-    b->common.callbacks.click = menu_switch_to_fisheye;
+    b = glCompButtonNew(p, 1, y, 42, 42, "");
+    {
+      char *fisheye = smyrnaPath("fisheye.png");
+      glCompButtonAddPngGlyph(b, fisheye);
+      free(fisheye);
+    }
+    b->base.common.callbacks.click = menu_switch_to_fisheye;
     toFisheye = b;
 
 
     /*switch to normal mode */
-    b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
-    glCompButtonAddPngGlyph(b, smyrnaPath("no_fisheye.png"));
-    b->common.callbacks.click = menu_switch_to_fisheye;
-    b->common.visible = 0;
+    b = glCompButtonNew(p, 1, y, 42, 42, "");
+    {
+      char *fisheye = smyrnaPath("no_fisheye.png");
+      glCompButtonAddPngGlyph(b, fisheye);
+      free(fisheye);
+    }
+    b->base.common.callbacks.click = menu_switch_to_fisheye;
+    b->base.common.visible = 0;
     toNormal = b;
 
     y=y+off;
-    b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
-    glCompButtonAddPngGlyph(b, smyrnaPath("3D.png"));
-    b->common.callbacks.click = switch2D3D;
+    b = glCompButtonNew(p, 1, y, 42, 42, "");
+    {
+      char *threed = smyrnaPath("3D.png");
+      glCompButtonAddPngGlyph(b, threed);
+      free(threed);
+    }
+    b->base.common.callbacks.click = switch2D3D;
     to3DBtn = b;
 
-
-    b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
-    glCompButtonAddPngGlyph(b, smyrnaPath("2D.png"));
-    b->common.callbacks.click = switch2D3D;
+    b = glCompButtonNew(p, 1, y, 42, 42, "");
+    {
+      char *twod = smyrnaPath("2D.png");
+      glCompButtonAddPngGlyph(b, twod);
+      free(twod);
+    }
+    b->base.common.callbacks.click = switch2D3D;
     glCompButtonHide(b);
     to2DBtn = b;
 
     y=y+off;
-    b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "N");
-    b->common.callbacks.click = selectnodes;
+    b = glCompButtonNew(p, 1, y, 42, 42, "N");
+    b->base.common.callbacks.click = selectnodes;
     b->groupid=-1;
     b->status = true;
 
     y=y+off;
-    b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "E");
-    b->common.callbacks.click = selectedges;
+    b = glCompButtonNew(p, 1, y, 42, 42, "E");
+    b->base.common.callbacks.click = selectedges;
     b->groupid=-1;
 
     p = glCompPanelNew(p, 1, 325, 45, 180);
-    p->common.align = glAlignTop;
-    p->common.data = 0;
-    p->common.borderWidth = 1;
+    p->base.common.align = glAlignTop;
+    p->base.common.data = 0;
+    p->base.common.borderWidth = 1;
     p->shadowwidth = 0;
 
     c.R = 0.80f;
@@ -287,67 +304,88 @@ glCompSet *glcreate_gl_topview_menu(void)
 
     y = 1;
 
-    b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
-    glCompButtonAddPngGlyph(b, smyrnaPath("details.png"));
-    b->common.callbacks.click = attrList;
-    b->common.color = c;
+    b = glCompButtonNew(p, 1, y, 42, 42, "");
+    {
+      char *details = smyrnaPath("details.png");
+      glCompButtonAddPngGlyph(b, details);
+      free(details);
+    }
+    b->base.common.callbacks.click = attrList;
+    b->base.common.color = c;
 	
     y = y + off;
 	
-	b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
-    glCompButtonAddPngGlyph(b, smyrnaPath("zoomin.png"));
+	b = glCompButtonNew(p, 1, y, 42, 42, "");
+    {
+      char *zoomin = smyrnaPath("zoomin.png");
+      glCompButtonAddPngGlyph(b, zoomin);
+      free(zoomin);
+    }
     b->groupid = 0;
-    b->common.callbacks.click = menu_click_zoom_plus;
-    b->common.color = c;
+    b->base.common.callbacks.click = menu_click_zoom_plus;
+    b->base.common.color = c;
     y = y + off;
 
-
-    b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
-    glCompButtonAddPngGlyph(b, smyrnaPath("zoomout.png"));
-    b->common.callbacks.click = menu_click_zoom_minus;
-    b->common.color = c;
+    b = glCompButtonNew(p, 1, y, 42, 42, "");
+    {
+      char *zoomout = smyrnaPath("zoomout.png");
+      glCompButtonAddPngGlyph(b, zoomout);
+      free(zoomout);
+    }
+    b->base.common.callbacks.click = menu_click_zoom_minus;
+    b->base.common.color = c;
 
     y = y + off;
 
-
-    b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
-    glCompButtonAddPngGlyph(b, smyrnaPath("center.png"));
-    b->common.callbacks.click = menu_click_center;
-    b->common.color = c;
+    b = glCompButtonNew(p, 1, y, 42, 42, "");
+    {
+      char *center = smyrnaPath("center.png");
+      glCompButtonAddPngGlyph(b, center);
+      free(center);
+    }
+    b->base.common.callbacks.click = menu_click_center;
+    b->base.common.color = c;
 
     p = glCompPanelNew(s, -250, 550, 150, 175);
-    p->common.borderWidth = 0;
+    p->base.common.borderWidth = 0;
     p->shadowwidth = 0;
-    p->common.color.R = 0;
-    p->common.color.G = 0;
-    p->common.color.B = 1;
-    p->common.color.A = 0.2f;
-    p->common.visible = 0;
+    p->base.common.color.R = 0;
+    p->base.common.color.G = 0;
+    p->base.common.color.B = 1;
+    p->base.common.color.A = 0.2f;
+    p->base.common.visible = 0;
     sel = p;
-    s->common.callbacks.mouseover = glCompMouseMove;
-    s->common.callbacks.mouseup = CBglCompMouseUp;
+    s->base.common.callbacks.mouseover = glCompMouseMove;
+    s->base.common.callbacks.mouseup = CBglCompMouseUp;
 
     p = glCompPanelNew(s, 25, 25, 52, 47);
-    p->common.align = glAlignRight;
-    p->common.data = 0;
-    p->common.color.A = 0;
+    p->base.common.align = glAlignRight;
+    p->base.common.data = 0;
+    p->base.common.color.A = 0;
 
     p = glCompPanelNew(p, 25, 0, 52, 110);
-    p->common.align = glAlignTop;
-    p->common.data = 0;
-    p->common.color.A = 0;
+    p->base.common.align = glAlignTop;
+    p->base.common.data = 0;
+    p->base.common.color.A = 0;
     p->shadowwidth = 0;
 
-    i = glCompImageNew((glCompObj *) p, 0, 0);
-    glCompImageLoadPng(i, smyrnaPath("mod_fisheye.png"));
+    i = glCompImageNew(p, 0, 0);
+    {
+      char *fisheye = smyrnaPath("mod_fisheye.png");
+      glCompImageLoadPng(i, fisheye);
+      free(fisheye);
+    }
     imgFisheye = i;
-    i->common.visible = 0;
+    i->base.common.visible = 0;
 
-    i = glCompImageNew((glCompObj *) p, 0, 52);
-    glCompImageLoadPng(i, smyrnaPath("mod_3D.png"));
+    i = glCompImageNew(p, 0, 52);
+    {
+      char *threed = smyrnaPath("mod_3D.png");
+      glCompImageLoadPng(i, threed);
+      free(threed);
+    }
     img3D = i;
-    i->common.visible = 0;
-    
+    i->base.common.visible = 0;
 
     return s;
 
