@@ -10,7 +10,6 @@
 
 #include <assert.h>
 #include "topviewfuncs.h"
-#include <cgraph/alloc.h>
 #include <cgraph/gv_ctype.h>
 #include <cgraph/cgraph.h>
 #include "smyrna_utils.h"
@@ -27,6 +26,7 @@
 #include <math.h>
 #include <stdbool.h>
 #include <stdlib.h>
+#include <util/alloc.h>
 
 static xdot *parseXdotwithattrs(void *e)
 {
@@ -109,8 +109,8 @@ static float getEdgeLength(Agedge_t *edge) {
     rv=sqrtf(rv);
     return rv;
 }
-static void glCompColorxlate(glCompColor* c,char* str)
-{
+
+static void glCompColorxlate(glCompColor *c, const char *str) {
         gvcolor_t cl;
 	colorxlate(str, &cl, RGBA_DOUBLE);
 	c->R=cl.u.RGBA[0];
@@ -142,7 +142,6 @@ static int object_color(void* obj,glCompColor* c)
     int return_value = 1;
     int objType;
     float Alpha = 1;
-    char* bf;
     Agsym_t* vis;
 
     objType=AGTYPE(obj);
@@ -161,7 +160,7 @@ static int object_color(void* obj,glCompColor* c)
 
     char *previous_color_scheme = setColorScheme(agget (obj, "colorscheme"));
     /*get objects's color attribute */
-    bf = getAttrStr(g,obj,"color",NULL);
+    const char *const bf = getAttrStr(g,obj,"color",NULL);
     if(bf && (*bf)) {
 	colorxlate(bf, &cl, RGBA_DOUBLE);
 	c->R = cl.u.RGBA[0];
