@@ -26,8 +26,6 @@
 #include <algorithm>
 #include <cassert>
 #include <gvc/gvc.h>
-#include <cgraph/alloc.h>
-#include <cgraph/exit.h>
 #include <cgraph/ingraphs.h>
 #include <cgraph/startswith.h>
 #include <common/render.h>
@@ -42,6 +40,8 @@
 #include <stddef.h>
 #include <string>
 #include <utility>
+#include <util/alloc.h>
+#include <util/exit.h>
 #include <vector>
 #include "openFile.h"
 
