@@ -16,14 +16,14 @@
 #include    <assert.h>
 #include    "convert.h"
 #include    <cgraph/agxbuf.h>
-#include    <cgraph/alloc.h>
-#include    <cgraph/exit.h>
 #include    <cgraph/gv_ctype.h>
 #include    <cgraph/list.h>
 #include    <cgraph/startswith.h>
-#include    <cgraph/unreachable.h>
 #include    <stdbool.h>
 #include    <stdio.h>
+#include    <util/alloc.h>
+#include    <util/exit.h>
+#include    <util/unreachable.h>
 #ifdef HAVE_EXPAT
 #include    <expat.h>
 #include    <limits.h>
