@@ -58,7 +58,6 @@ extern Agraph_t *Ag_G_global;
 extern char *AgDataRecName;
 
 	/* set ordering disciplines */
-extern Dtdisc_t Ag_subnode_id_disc;
 extern Dtdisc_t Ag_subnode_seq_disc;
 extern Dtdisc_t Ag_mainedge_id_disc;
 extern Dtdisc_t Ag_subedge_id_disc;
@@ -86,7 +85,7 @@ Dict_t *agdtopen(Agraph_t * g, Dtdisc_t * disc, Dtmethod_t * method);
 void agdtdisc(Agraph_t * g, Dict_t * dict, Dtdisc_t * disc);
 int agdtdelete(Agraph_t * g, Dict_t * dict, void *obj);
 int agdtclose(Agraph_t * g, Dict_t * dict);
-void agdictobjfree(void *p, Dtdisc_t *disc);
+void agdictobjfree(void *p);
 
 /** @addtogroup cgraph_attr
  *  @{
