@@ -15,6 +15,7 @@
 
 #include <assert.h>
 #include <cgraph/cghdr.h>
+#include <cgraph/node_set.h>
 #include <stddef.h>
 #include <stdbool.h>
 
@@ -142,14 +143,7 @@ static Agedge_t *agfindedge_by_id(Agraph_t * g, Agnode_t * t, Agnode_t * h,
 
 Agsubnode_t *agsubrep(Agraph_t * g, Agnode_t * n)
 {
-    Agsubnode_t *sn, template;
-
-	if (g == n->root) sn = &(n->mainsub);
-	else {
-			template.node = n;
-			sn = dtsearch(g->n_id, &template);
-	}
-    return sn;
+  return g == n->root ? &n->mainsub : node_set_find(g->n_id, n->base.tag.id);
 }
 
 static void ins(Dict_t * d, Dtlink_t ** set, Agedge_t * e)
@@ -379,14 +373,9 @@ Agedge_t *agsubedge(Agraph_t * g, Agedge_t * e, int cflag)
 }
 
 /* edge comparison.  AGTYPE(e) == 0 means ID is a wildcard. */
-static int agedgeidcmpf(Dict_t * d, void *arg_e0, void *arg_e1, Dtdisc_t * disc)
-{
-    Agedge_t *e0, *e1;
-
-    (void)d;
-    e0 = arg_e0;
-    e1 = arg_e1;
-    (void)disc;
+static int agedgeidcmpf(void *arg_e0, void *arg_e1) {
+    Agedge_t *e0 = arg_e0;
+    Agedge_t *e1 = arg_e1;
 
     if (AGID(e0->node) < AGID(e1->node)) return -1;
     if (AGID(e0->node) > AGID(e1->node)) return 1;
@@ -399,14 +388,9 @@ static int agedgeidcmpf(Dict_t * d, void *arg_e0, void *arg_e1, Dtdisc_t * disc)
 }
 
 /* edge comparison.  for ordered traversal. */
-static int agedgeseqcmpf(Dict_t * d, void *arg_e0, void *arg_e1, Dtdisc_t * disc)
-{
-    Agedge_t *e0, *e1;
-
-    (void)d;
-    e0 = arg_e0;
-    e1 = arg_e1;
-    (void)disc;
+static int agedgeseqcmpf(void *arg_e0, void *arg_e1) {
+    Agedge_t *e0 = arg_e0;
+    Agedge_t *e1 = arg_e1;
     assert(arg_e0 && arg_e1);
 
     if (e0->node != e1->node) {
@@ -447,6 +431,7 @@ and to expose them to foreign languages without C preprocessor. */
 #ifdef ageqedge
 #undef ageqedge
 #endif
+CGRAPH_API int ageqedge(Agedge_t *e, Agedge_t *f);
 CGRAPH_API int ageqedge(Agedge_t * e, Agedge_t * f)
 {
     return AGEQEDGE(e, f);
@@ -455,6 +440,7 @@ CGRAPH_API int ageqedge(Agedge_t * e, Agedge_t * f)
 #ifdef agmkout
 #undef agmkout
 #endif
+CGRAPH_API Agedge_t *agmkout(Agedge_t *e);
 CGRAPH_API Agedge_t *agmkout(Agedge_t * e)
 {
     return AGMKOUT(e);
@@ -463,6 +449,7 @@ CGRAPH_API Agedge_t *agmkout(Agedge_t * e)
 #ifdef agmkin
 #undef agmkin
 #endif
+CGRAPH_API Agedge_t *agmkin(Agedge_t *e);
 CGRAPH_API Agedge_t *agmkin(Agedge_t * e)
 {
     return AGMKIN(e);
@@ -471,6 +458,7 @@ CGRAPH_API Agedge_t *agmkin(Agedge_t * e)
 #ifdef agtail
 #undef agtail
 #endif
+CGRAPH_API Agnode_t *agtail(Agedge_t *e);
 CGRAPH_API Agnode_t *agtail(Agedge_t * e)
 {
     return AGTAIL(e);
@@ -479,6 +467,7 @@ CGRAPH_API Agnode_t *agtail(Agedge_t * e)
 #ifdef aghead
 #undef aghead
 #endif
+CGRAPH_API Agnode_t *aghead(Agedge_t *e);
 CGRAPH_API Agnode_t *aghead(Agedge_t * e)
 {
     return AGHEAD(e);
@@ -487,6 +476,7 @@ CGRAPH_API Agnode_t *aghead(Agedge_t * e)
 #ifdef agopp
 #undef agopp
 #endif
+CGRAPH_API Agedge_t *agopp(Agedge_t *e);
 CGRAPH_API Agedge_t *agopp(Agedge_t * e)
 {
     return AGOPP(e);
