@@ -16,17 +16,17 @@
 #include "htmlparse.h"
 #include <common/htmllex.h>
 #include <cdt/cdt.h>
-#include <cgraph/alloc.h>
 #include <cgraph/gv_ctype.h>
 #include <cgraph/startswith.h>
-#include <cgraph/strcasecmp.h>
 #include <cgraph/strview.h>
 #include <cgraph/tokenize.h>
-#include <cgraph/unused.h>
 #include <limits.h>
 #include <stdbool.h>
 #include <stddef.h>
 #include <stdint.h>
+#include <util/alloc.h>
+#include <util/strcasecmp.h>
+#include <util/unused.h>
 
 #ifdef HAVE_EXPAT
 #ifdef _WIN32
