@@ -34,14 +34,9 @@
 #include <common/render.h>
 #include <common/htmltable.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/prisize_t.h>
 #include <common/pointset.h>
 #include <common/intset.h>
 #include <cdt/cdt.h>
-#include <cgraph/alloc.h>
-#include <cgraph/exit.h>
-#include <cgraph/strcasecmp.h>
-#include <cgraph/unreachable.h>
 #include <float.h>
 #include <inttypes.h>
 #include <limits.h>
@@ -50,6 +45,12 @@
 #include <stdbool.h>
 #include <stdint.h>
 #include <stdio.h>
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/prisize_t.h>
+#include <util/strcasecmp.h>
+#include <util/streq.h>
+#include <util/unreachable.h>
 
 #define DEFAULT_BORDER    1
 #define DEFAULT_CELLPADDING  2
@@ -69,8 +70,7 @@ typedef struct {
 static void printCell(htmlcell_t * cp, int ind);
 #endif
 
-/* pushFontInfo:
- * Replace current font attributes in env with ones from fp,
+/* Replace current font attributes in env with ones from fp,
  * storing old attributes in savp. We only deal with attributes
  * set in env. The attributes are restored via popFontInfo.
  */
@@ -100,8 +100,7 @@ pushFontInfo(htmlenv_t * env, textfont_t * fp, textfont_t * savp)
     }
 }
 
-/* popFontInfo:
- * Restore saved font attributes.
+/* Restore saved font attributes.
  * Copy only set values.
  */
 static void popFontInfo(htmlenv_t * env, textfont_t * savp)
@@ -221,8 +220,7 @@ static void doSide(GVJ_t * job, pointf p, double wd, double ht)
     gvrender_box(job, BF, 1);
 }
 
-/* mkPts:
- * Convert boxf into four corner points
+/* Convert boxf into four corner points
  * If border is > 1, inset the points by half the border.
  * It is assumed AF is pointf[4], so the data is store there
  * and AF is returned.
@@ -246,8 +244,7 @@ static pointf *mkPts(pointf * AF, boxf b, int border)
     return AF;
 }
 
-/* doBorder:
- * Draw a rectangular border for the box b.
+/* Draw a rectangular border for the box b.
  * Handles dashed and dotted styles, rounded corners.
  * Also handles thick lines.
  * Assume dp->border > 0
@@ -344,8 +341,7 @@ static void doBorder(GVJ_t * job, htmldata_t * dp, boxf b)
     }
 }
 
-/* setFill:
- * Set up fill values from given color; make pen transparent.
+/* Set up fill values from given color; make pen transparent.
  * Return type of fill required.
  */
 static int setFill(GVJ_t *job, char *color, int angle, htmlstyle_t style,
@@ -370,8 +366,7 @@ static int setFill(GVJ_t *job, char *color, int angle, htmlstyle_t style,
     return filled;
 }
 
-/* initAnchor:
- * Save current map values.
+/* Save current map values.
  * Initialize fields in job->obj pertaining to anchors.
  * In particular, this also sets the output rectangle.
  * If there is something to do, 
@@ -424,8 +419,7 @@ initAnchor(GVJ_t * job, htmlenv_t * env, htmldata_t * data, boxf b,
 #define RESET(fld) \
   if(obj->fld != save->fld) {free(obj->fld); obj->fld = save->fld;}
 
-/* endAnchor:
- * Pop context pushed by initAnchor.
+/* Pop context pushed by initAnchor.
  * This is done by ending current anchor, restoring old values and
  * freeing new.
  *
@@ -448,11 +442,9 @@ static void endAnchor(GVJ_t * job, htmlmap_data_t * save)
     obj->explicit_tooltip = save->explicit_tooltip;
 }
 
-/* forward declaration */
 static void emit_html_cell(GVJ_t * job, htmlcell_t * cp, htmlenv_t * env);
 
-/* emit_html_rules:
- * place vertical and horizontal lines between adjacent cells and
+/* place vertical and horizontal lines between adjacent cells and
  * extend the lines to intersect the rounded table boundary 
  */
 static void
@@ -476,7 +468,7 @@ emit_html_rules(GVJ_t * job, htmlcell_t * cp, htmlenv_t * env, char *color, html
     pts.UR.y += pos.y;
 
     //Determine vertical line coordinate and length
-    if ((cp->ruled & HTML_VRULE) && cp->col + cp->colspan < cp->parent->column_count) {
+    if (cp->vruled && cp->col + cp->colspan < cp->parent->column_count) {
 	if (cp->row == 0) {	// first row
 	    // extend to center of table border and add half cell spacing
 	    base = cp->parent->data.border + cp->parent->data.space / 2;
@@ -494,7 +486,7 @@ emit_html_rules(GVJ_t * job, htmlcell_t * cp, htmlenv_t * env, char *color, html
 	doSide(job, rule_pt, 0, rule_length);
     }
     //Determine the horizontal coordinate and length
-    if ((cp->ruled & HTML_HRULE) && cp->row + cp->rowspan < cp->parent->row_count) {
+    if (cp->hruled && cp->row + cp->rowspan < cp->parent->row_count) {
 	if (cp->col == 0) {	// first column 
 	    // extend to center of table border and add half cell spacing
 	    base = cp->parent->data.border + cp->parent->data.space / 2;
@@ -552,7 +544,7 @@ static void emit_html_tbl(GVJ_t * job, htmltbl_t * tbl, htmlenv_t * env)
 
 	/* Fill first */
 	if (tbl->data.bgcolor) {
-	    char *clrs[2];
+	    char *clrs[2] = {0};
 	    int filled =
 		setFill(job, tbl->data.bgcolor, tbl->data.gradientangle,
 			tbl->data.style, clrs);
@@ -562,6 +554,7 @@ static void emit_html_tbl(GVJ_t * job, htmltbl_t * tbl, htmlenv_t * env)
 	    } else
 		gvrender_box(job, pts, filled);
 	    free(clrs[0]);
+	    free(clrs[1]);
 	}
 
 	while (*cells) {
@@ -577,7 +570,7 @@ static void emit_html_tbl(GVJ_t * job, htmltbl_t * tbl, htmlenv_t * env)
 	cells = tbl->u.n.cells;
 	gvrender_set_penwidth(job, 1.0);
 	while ((cp = *cells++)) {
-	    if (cp->ruled)
+	    if (cp->hruled || cp->vruled)
 		emit_html_rules(job, cp, env, tbl->data.pencolor, *cells);
 	}
 
@@ -598,8 +591,7 @@ static void emit_html_tbl(GVJ_t * job, htmltbl_t * tbl, htmlenv_t * env)
 	popFontInfo(env, &savef);
 }
 
-/* emit_html_img:
- * The image will be centered in the given box.
+/* The image will be centered in the given box.
  * Scaling is determined by either the image's scale attribute,
  * or the imagescale attribute of the graph object being drawn.
  */
@@ -682,8 +674,7 @@ static void emit_html_cell(GVJ_t * job, htmlcell_t * cp, htmlenv_t * env)
     }
 }
 
-/* allocObj:
- * Push new obj on stack to be used in common by all 
+/* Push new obj on stack to be used in common by all 
  * html elements with anchors.
  * This inherits the type, emit_state, and object of the
  * parent, as well as the url, explicit, target and tooltip.
@@ -751,8 +742,6 @@ heightOfLbl (htmllabel_t * lp)
     return sz;
 }
 
-/* emit_html_label:
- */
 void emit_html_label(GVJ_t * job, htmllabel_t * lp, textlabel_t * tp)
 {
     htmlenv_t env;
@@ -847,17 +836,16 @@ static void free_html_cell(htmlcell_t * cp)
     free(cp);
 }
 
-/* free_html_tbl:
- * If tbl->n_rows is negative, table is in initial state from
+/* If tbl->row_count is `SIZE_MAX`, table is in initial state from
  * HTML parse, with data stored in u.p. Once run through processTbl,
- * data is stored in u.n and tbl->n_rows is > 0.
+ * data is stored in u.n and tbl->row_count is < `SIZE_MAX`.
  */
 static void free_html_tbl(htmltbl_t * tbl)
 {
     htmlcell_t **cells;
 
     if (tbl->row_count == SIZE_MAX) { // raw, parsed table
-	dtclose(tbl->u.p.rows);
+	rows_free(&tbl->u.p.rows);
     } else {
 	cells = tbl->u.n.cells;
 
@@ -885,7 +873,7 @@ void free_html_label(htmllabel_t * lp, int root)
 	free(lp);
 }
 
-static htmldata_t *portToTbl(htmltbl_t *, char *);	/* forward declaration */
+static htmldata_t *portToTbl(htmltbl_t *, char *);
 
 static htmldata_t *portToCell(htmlcell_t * cp, char *id)
 {
@@ -901,8 +889,7 @@ static htmldata_t *portToCell(htmlcell_t * cp, char *id)
     return rv;
 }
 
-/* portToTbl:
- * See if tp or any of its child cells has the given port id.
+/* See if tp or any of its child cells has the given port id.
  * If true, return corresponding box.
  */
 static htmldata_t *portToTbl(htmltbl_t * tp, char *id)
@@ -925,13 +912,12 @@ static htmldata_t *portToTbl(htmltbl_t * tp, char *id)
     return rv;
 }
 
-/* html_port:
- * See if edge port corresponds to part of the html node.
- * Assume pname != "".
+/* See if edge port corresponds to part of the html node.
  * If successful, return pointer to port's box.
  * Else return NULL.
  */
 boxf *html_port(node_t *n, char *pname, unsigned char *sides){
+    assert(pname != NULL && !streq(pname, ""));
     htmldata_t *tp;
     htmllabel_t *lbl = ND_label(n)->u.html;
     boxf *rv = NULL;
@@ -1084,12 +1070,9 @@ static int size_html_txt(GVC_t *gvc, htmltxt_t * ftxt, htmlenv_t * env)
     return 0;
 }
 
-/* forward declarion for recursive usage */
 static int size_html_tbl(graph_t * g, htmltbl_t * tbl, htmlcell_t * parent,
 			 htmlenv_t * env);
 
-/* size_html_img:
- */
 static int size_html_img(htmlimg_t * img, htmlenv_t * env)
 {
     box b;
@@ -1110,8 +1093,6 @@ static int size_html_img(htmlimg_t * img, htmlenv_t * env)
     return rv;
 }
 
-/* size_html_cell:
- */
 static int
 size_html_cell(graph_t * g, htmlcell_t * cp, htmltbl_t * parent,
 	       htmlenv_t * env)
@@ -1196,53 +1177,36 @@ static uint16_t findCol(PointSet *ps, int row, int col, htmlcell_t *cellp) {
     return (uint16_t)col;
 }
 
-/* processTbl:
- * Convert parser representation of cells into final form.
+/* Convert parser representation of cells into final form.
  * Find column and row positions of cells.
  * Recursively size cells.
  * Return 1 if problem sizing a cell.
  */
 static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
 {
-    pitem *rp;
-    pitem *cp;
-    Dt_t *cdict;
-    htmlcell_t *cellp;
     htmlcell_t **cells;
-    Dt_t *rows = tbl->u.p.rows;
+    rows_t rows = tbl->u.p.rows;
     int rv = 0;
     size_t n_rows = 0;
     size_t n_cols = 0;
     PointSet *ps = newPS();
     Dt_t *is = openIntSet();
 
-    rp = (pitem *) dtflatten(rows);
     size_t cnt = 0;
-    uint16_t r = 0;
-    while (rp) {
-	cdict = rp->u.rp;
-	cp = (pitem *) dtflatten(cdict);
-	while (cp) {
-	    cellp = cp->u.cp;
-	    cnt++;
-	    cp = (pitem *)dtlink(cdict, cp);
-	}
+    for (uint16_t r = 0; r < rows_size(&rows); ++r) {
+	row_t *rp = rows_get(&rows, r);
+	cnt += cells_size(&rp->rp);
 	if (rp->ruled) {
 	    addIntSet(is, r + 1);
 	}
-	rp = (pitem *)dtlink(rows, rp);
-	r++;
     }
 
     cells = tbl->u.n.cells = gv_calloc(cnt + 1, sizeof(htmlcell_t *));
-    rp = (pitem *) dtflatten(rows);
-    r = 0;
-    while (rp) {
-	cdict = rp->u.rp;
-	cp = (pitem *) dtflatten(cdict);
+    for (uint16_t r = 0; r < rows_size(&rows); ++r) {
+	row_t *rp = rows_get(&rows, r);
 	uint16_t c = 0;
-	while (cp) {
-	    cellp = cp->u.cp;
+	for (size_t i = 0; i < cells_size(&rp->rp); ++i) {
+	    htmlcell_t *cellp = cells_get(&rp->rp, i);
 	    *cells++ = cellp;
 	    rv |= size_html_cell(g, cellp, tbl, env);
 	    c = findCol(ps, r, c, cellp);
@@ -1252,15 +1216,12 @@ static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
 	    n_cols = MAX(c, n_cols);
 	    n_rows = MAX(r + cellp->rowspan, n_rows);
 	    if (inIntSet(is, r + cellp->rowspan))
-		cellp->ruled |= HTML_HRULE;
-	    cp = (pitem *)dtlink(cdict, cp);
+		cellp->hruled = true;
 	}
-	rp = (pitem *)dtlink(rows, rp);
-	r++;
     }
     tbl->row_count = n_rows;
     tbl->column_count = n_cols;
-    dtclose(rows);
+    rows_free(&rows);
     dtclose(is);
     freePS(ps);
     return rv;
@@ -1272,8 +1233,7 @@ static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
  */
 #define SPLIT(x,n,s) (((x) - ((s)-1)*((n)-1)) / (n))
 
-/* sizeLinearArray:
- * Determine sizes of rows and columns. The size of a column is the
+/* Determine sizes of rows and columns. The size of a column is the
  * maximum width of any cell in it. Similarly for rows.
  * A cell spanning columns contributes proportionately to each column
  * it is in.
@@ -1312,9 +1272,7 @@ static void sizeLinearArray(htmltbl_t * tbl)
     }
 }
 
-/* closeGraphs:
- * Clean up graphs made for setting column and row widths.
- */
+/// Clean up graphs made for setting column and row widths.
 static void closeGraphs(graph_t * rowg, graph_t * colg)
 {
     node_t *n;
@@ -1327,8 +1285,7 @@ static void closeGraphs(graph_t * rowg, graph_t * colg)
     agclose(colg);
 }
 
-/* checkChain:
- * For each pair of nodes in the node list, add an edge if none exists.
+/* For each pair of nodes in the node list, add an edge if none exists.
  * Assumes node list has nodes ordered correctly.
  */
 static void checkChain(graph_t * g)
@@ -1349,8 +1306,7 @@ static void checkChain(graph_t * g)
     }
 }
 
-/* checkEdge:
- * Check for edge in g. If it exists, set its minlen to max of sz and
+/* Check for edge in g. If it exists, set its minlen to max of sz and
  * current minlen. Else, create it and set minlen to sz.
  */
 static void checkEdge(graph_t *g, node_t *t, node_t *h, double sz) {
@@ -1371,8 +1327,7 @@ static void checkEdge(graph_t *g, node_t *t, node_t *h, double sz) {
     }
 }
 
-/* makeGraphs:
- * Generate dags modeling the row and column constraints.
+/* Generate dags modeling the row and column constraints.
  * If the table has column_count columns, we create the graph
  *  0 -> 1 -> 2 -> ... -> column_count
  * and if a cell starts in column c with span colspan, with
@@ -1440,8 +1395,7 @@ static void makeGraphs(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
     checkChain(rowg);
 }
 
-/* setSizes:
- * Use rankings to determine cell dimensions. The rank values
+/* Use rankings to determine cell dimensions. The rank values
  * give the coordinate, so to get the width/height, we have
  * to subtract the previous value.
  */
@@ -1466,8 +1420,7 @@ static void setSizes(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
 
 }
 
-/* sizeArray:
- * Set column and row sizes. Optimize for minimum width and
+/* Set column and row sizes. Optimize for minimum width and
  * height. Where there is slack, try to distribute evenly.
  * We do this by encoding cells as edges with min length is
  * a dag on a chain. We then run network simplex, using
@@ -1502,8 +1455,7 @@ static void sizeArray(htmltbl_t * tbl)
 
 static void pos_html_tbl(htmltbl_t *, boxf, unsigned char);
 
-/* pos_html_img:
- * Place image in cell
+/* Place image in cell
  * storing allowed space handed by parent cell.
  * How this space is used is handled in emit_html_img.
  */
@@ -1512,9 +1464,7 @@ static void pos_html_img(htmlimg_t * cp, boxf pos)
     cp->box = pos;
 }
 
-/* pos_html_txt:
- * Set default alignment.
- */
+/// Set default alignment.
 static void pos_html_txt(htmltxt_t * ftxt, char c)
 {
     for (size_t i = 0; i < ftxt->nspans; i++) {
@@ -1523,8 +1473,6 @@ static void pos_html_txt(htmltxt_t * ftxt, char c)
     }
 }
 
-/* pos_html_cell:
- */
 static void pos_html_cell(htmlcell_t *cp, boxf pos, unsigned char sides) {
     double delx, dely;
     pointf oldsz;
@@ -1669,8 +1617,7 @@ static void pos_html_cell(htmlcell_t *cp, boxf pos, unsigned char sides) {
     }
 }
 
-/* pos_html_tbl:
- * Position table given its box, then calculate
+/* Position table given its box, then calculate
  * the position of each cell. In addition, set the sides
  * attribute indicating which external sides of the node
  * are accessible to the table.
@@ -1769,8 +1716,7 @@ static void pos_html_tbl(htmltbl_t *tbl, boxf pos, unsigned char sides) {
     tbl->data.box = pos;
 }
 
-/* size_html_tbl:
- * Determine the size of a table by first determining the
+/* Determine the size of a table by first determining the
  * size of each cell.
  */
 static int
@@ -1981,9 +1927,7 @@ static char *getPenColor(void *obj)
 	return NULL;
 }
 
-/* make_html_label:
- * Return non-zero if problem parsing HTML. In this case, use object name.
- */
+/// Return non-zero if problem parsing HTML. In this case, use object name.
 int make_html_label(void *obj, textlabel_t * lp)
 {
     int rv;
