@@ -11,25 +11,26 @@
  *************************************************************************/
 
 #include <sys/stat.h>
-#include <cgraph/alloc.h>
 #include <common/render.h>
 #include <gvc/gvio.h>
-#include <cgraph/strcasecmp.h>
 #include <stdbool.h>
 #include <stdio.h>
+#include <util/alloc.h>
+#include <util/gv_fopen.h>
+#include <util/strcasecmp.h>
 
 static int N_EPSF_files;
 static Dict_t *EPSF_contents;
 
-static void ps_image_free(usershape_t *p, Dtdisc_t *disc) {
-    (void)disc;
+static void ps_image_free(void *shape) {
+    usershape_t *p = shape;
     free(p->data);
 }
 
 static Dtdisc_t ImageDictDisc = {
     .key = offsetof(usershape_t, name),
     .size = -1,
-    .freef = (Dtfree_f)ps_image_free,
+    .freef = ps_image_free,
 };
 
 static usershape_t *user_init(const char *str)
@@ -46,7 +47,7 @@ static usershape_t *user_init(const char *str)
     if (us)
 	return us;
 
-    if (!(fp = fopen(str, "r"))) {
+    if (!(fp = gv_fopen(str, "r"))) {
 	agwarningf("couldn't open epsf file %s\n", str);
 	return NULL;
     }
@@ -102,8 +103,8 @@ void epsf_init(node_t * n)
 	usershape_t *us = user_init(str);
 	if (!us)
 	    return;
-	int dx = us->w;
-	int dy = us->h;
+	const double dx = us->w;
+	const double dy = us->h;
 	ND_width(n) = PS2INCH(dx);
 	ND_height(n) = PS2INCH(dy);
 	ND_shape_info(n) = desc = gv_alloc(sizeof(epsf_t));
@@ -157,7 +158,7 @@ void cat_libfile(GVJ_t * job, const char **arglib, const char **stdlib)
 	    if (!safepath) {
 		agwarningf("can't find library file %s\n", p);
 	    }
-            else if ((fp = fopen(safepath, "r"))) {
+            else if ((fp = gv_fopen(safepath, "r"))) {
                 while (true) {
                     char bp[BUFSIZ] = {0};
                     size_t r = fread(bp, 1, sizeof(bp), fp);
