@@ -11,7 +11,6 @@
  *************************************************************************/
 
 #include <common/render.h>
-#include <cgraph/alloc.h>
 #include <cgraph/agxbuf.h>
 #include <cgraph/gv_ctype.h>
 #include <cgraph/gv_math.h>
@@ -23,12 +22,13 @@
 #include <math.h>
 #include <gvc/gvc.h>
 #include <cgraph/startswith.h>
-#include <cgraph/strcasecmp.h>
 #include <cgraph/strview.h>
 #include <stddef.h>
 #include <stdbool.h>
 #include <stdint.h>
 #include <unistd.h>
+#include <util/alloc.h>
+#include <util/strcasecmp.h>
 #include <util/streq.h>
 
 int late_int(void *obj, attrsym_t *attr, int defaultValue, int minimum) {
