@@ -15,12 +15,9 @@
  * expression library evaluator
  */
 
-#include <cgraph/alloc.h>
 #include <cgraph/agxbuf.h>
 #include <cgraph/strview.h>
-#include <cgraph/exit.h>
 #include <cgraph/gv_ctype.h>
-#include <cgraph/unreachable.h>
 #include <expr/exlib.h>
 #include <expr/exop.h>
 #include <inttypes.h>
@@ -31,6 +28,9 @@
 #include <string.h>
 #include <assert.h>
 #include <time.h>
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/unreachable.h>
 #ifdef _WIN32
 #define srand48 srand
 #define drand48 rand
