@@ -8,23 +8,22 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <cgraph/alloc.h>
 #include <glcomp/glcompimage.h>
 #include <glcomp/glcompfont.h>
 #include <glcomp/glcompset.h>
 #include <glcomp/glutils.h>
 #include <glcomp/glcomptexture.h>
 #include <stdbool.h>
+#include <stddef.h>
+#include <util/alloc.h>
 
-glCompImage *glCompImageNew(glCompObj *par, float x, float y) {
+glCompImage *glCompImageNew(void *par, float x, float y) {
     glCompImage *p = gv_alloc(sizeof(glCompImage));
-    glCompInitCommon((glCompObj *) p, par, x, y);
-    p->objType = glImageObj;
-
-    p->objType = glImageObj;
+    glCompInitCommon(&p->base, par, x, y);
+    p->base.objType = glImageObj;
     p->stretch = 0;
     p->texture = NULL;
-    p->common.functions.draw = glCompImageDraw;
+    p->base.common.functions.draw = glCompImageDraw;
     return p;
 }
 
@@ -33,38 +32,41 @@ glCompImage *glCompImageNew(glCompObj *par, float x, float y) {
  * At present, we assume png input.
  * Return 0 on failure.
  */
-glCompImage *glCompImageNewFile(float x, float y, char *imgfile) {
+glCompImage *glCompImageNewFile(float x, float y, const char *imgfile) {
     int imageWidth, imageHeight;
-    unsigned char *data = glCompLoadPng (imgfile, &imageWidth, &imageHeight);
+    cairo_surface_t *surface = NULL;
+    const unsigned char *data = glCompLoadPng(&surface, imgfile, &imageWidth,
+                                              &imageHeight);
     glCompImage *p;
 
     if (!data) return NULL;
     p = glCompImageNew(NULL, x, y);
     if (!glCompImageLoad(p, data, imageWidth, imageHeight, 0)) {
 	glCompImageDelete (p);
-	return NULL;
+	p = NULL;
     }
+    cairo_surface_destroy(surface);
     return p;
 }
 
 void glCompImageDelete(glCompImage * p)
 {
-    glCompEmptyCommon(&p->common);
+    glCompEmptyCommon(&p->base.common);
     if (p->texture)
 	glCompDeleteTexture(p->texture);
     free(p);
 }
 
-int glCompImageLoad(glCompImage *i, unsigned char *data, int width, int height,
-                    bool is2D) {
+int glCompImageLoad(glCompImage *i, const unsigned char *data, int width,
+                    int height, bool is2D) {
     if (data != NULL) {		/*valid image data */
 	glCompDeleteTexture(i->texture);
 	i->texture =
-	    glCompSetAddNewTexImage(i->common.compset, width, height, data,
+	    glCompSetAddNewTexImage(i->base.common.compset, width, height, data,
 				    is2D);
 	if (i->texture) {
-	    i->common.width = width;
-	    i->common.height = height;
+	    i->base.common.width = width;
+	    i->base.common.height = height;
 	    return 1;
 	}
 
@@ -72,21 +74,24 @@ int glCompImageLoad(glCompImage *i, unsigned char *data, int width, int height,
     return 0;
 }
 
-int glCompImageLoadPng(glCompImage *i, char *pngFile) {
+int glCompImageLoadPng(glCompImage *i, const char *pngFile) {
     int imageWidth, imageHeight;
-    unsigned char *data;
-    data = glCompLoadPng (pngFile, &imageWidth, &imageHeight);
-    return glCompImageLoad(i, data, imageWidth, imageHeight, 1);
+    cairo_surface_t *surface = NULL;
+    const unsigned char *data = glCompLoadPng(&surface, pngFile, &imageWidth,
+                                              &imageHeight);
+    const int rc = glCompImageLoad(i, data, imageWidth, imageHeight, 1);
+    cairo_surface_destroy(surface);
+    return rc;
 }
 
 void glCompImageDraw(void *obj)
 {
     glCompImage *p = obj;
-    glCompCommon ref = p->common;
+    glCompCommon ref = p->base.common;
     float w,h,d;
 
-    glCompCalcWidget((glCompCommon *) p->common.parent, &p->common, &ref);
-    if (!p->common.visible)
+    glCompCalcWidget(p->base.common.parent, &p->base.common, &ref);
+    if (!p->base.common.visible)
 	return;
     if (!p->texture)
 	return;
@@ -100,7 +105,7 @@ void glCompImageDraw(void *obj)
     {
 	w = p->width;
 	h = p->height;
-	d = (float)p->common.layer * GLCOMPSET_BEVEL_DIFF;
+	d = (float)p->base.common.layer * GLCOMPSET_BEVEL_DIFF;
 	glDisable(GL_BLEND);
 	glEnable(GL_TEXTURE_2D);
 	glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_DECAL);
