@@ -30,11 +30,11 @@
 #include        <gvc/gvio.h>
 
 #include	<common/const.h>
-#include <cgraph/alloc.h>
 #include <cgraph/list.h>
 #include <cgraph/startswith.h>
-#include <cgraph/strcasecmp.h>
 #include <cgraph/strview.h>
+#include <util/alloc.h>
+#include <util/strcasecmp.h>
 
 /*
  * Define an apis array of name strings using an enumerated api_t as index.
