@@ -17,6 +17,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <errno.h>
+#include <util/gv_fopen.h>
 
 #ifdef _WIN32
 #include <windows.h>
@@ -29,7 +30,6 @@
 #include <common/types.h>
 #include <common/usershape.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/gv_ctype.h>
 #include <cgraph/strview.h>
 #include <common/utils.h>
@@ -37,6 +37,7 @@
 #include <gvc/gvplugin.h>
 #include <gvc/gvcint.h>
 #include <gvc/gvcproc.h>
+#include <util/alloc.h>
 
 extern char *Gvimagepath;
 extern char *HTTPServerEnVar;
@@ -636,7 +637,7 @@ bool gvusershape_file_access(usershape_t *us)
 	    agwarningf("Filename \"%s\" is unsafe\n", us->name);
 	    return false;
 	}
-	us->f = fopen(fn, "rb");
+	us->f = gv_fopen(fn, "rb");
 	if (us->f == NULL) {
 	    agwarningf("%s while opening %s\n", strerror(errno), fn);
 	    return false;
@@ -782,7 +783,7 @@ point gvusershape_size(graph_t * g, char *name)
     if ((dpi.y = GD_drawing(g)->dpi) >= 1.0)
 	dpi.x = dpi.y;
     else
-	dpi.x = dpi.y = (double)DEFAULT_DPI;
+	dpi.x = dpi.y = DEFAULT_DPI;
 
     us = gvusershape_open (name);
     rv = gvusershape_size_dpi (us, dpi);
