@@ -20,12 +20,8 @@
 #include <gvpr/compile.h>
 #include <assert.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/cgraph.h>
-#include <cgraph/exit.h>
-#include <cgraph/prisize_t.h>
 #include <cgraph/startswith.h>
-#include <cgraph/unreachable.h>
 #include <ast/error.h>
 #include <gvpr/actions.h>
 #include <inttypes.h>
@@ -35,6 +31,10 @@
 #include <stdint.h>
 #include <stdio.h>
 #include <math.h>
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/prisize_t.h>
+#include <util/unreachable.h>
 
 static int isedge(Agobj_t *obj) {
   return AGTYPE(obj) == AGOUTEDGE || AGTYPE(obj) == AGINEDGE;
