@@ -20,14 +20,10 @@
 #include "builddate.h"
 #include <gvpr/gprstate.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/cgraph.h>
 #include <cgraph/gv_ctype.h>
 #include <cgraph/ingraphs.h>
-#include <cgraph/exit.h>
-#include <cgraph/queue.h>
-#include <cgraph/stack.h>
-#include <cgraph/unreachable.h>
+#include <cgraph/list.h>
 #include <common/globals.h>
 #include <gvpr/compile.h>
 #include <gvpr/gvpr.h>
@@ -39,6 +35,9 @@
 #include <string.h>
 #include <setjmp.h>
 #include <getopt.h>
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/unreachable.h>
 
 #ifndef DFLT_GVPRPATH
 #define DFLT_GVPRPATH    "."
@@ -198,8 +197,6 @@ concat (char* pfx, char* sfx)
  * If arg contains '/', return arg.
  * Else search directories in GVPRPATH for arg.
  * Return NULL on error.
- * 
- * FIX - use pathinclude/pathfind
  */
 static char *resolve(char *arg, int verbose) {
     char *path;
@@ -535,10 +532,12 @@ static trav_fns DFSfns = { agfstedge, agnxtedge, 1, 0 };
 static trav_fns FWDfns = { agfstout, agnxtout_, 0, 0 };
 static trav_fns REVfns = { agfstin, agnxtin_, 0, 0 };
 
+DEFINE_LIST(node_queue, Agnode_t *)
+
 static void travBFS(Gpr_t * state, Expr_t* prog, comp_block * xprog)
 {
     nodestream nodes;
-    queue_t q = {0};
+    node_queue_t q = {0};
     ndata *nd;
     Agnode_t *n;
     Agedge_t *cure;
@@ -552,8 +551,9 @@ static void travBFS(Gpr_t * state, Expr_t* prog, comp_block * xprog)
 	if (MARKED(nd))
 	    continue;
 	PUSH(nd, 0);
-	queue_push(&q, n);
-	while ((n = queue_pop(&q))) {
+	node_queue_push_back(&q, n);
+	while (!node_queue_is_empty(&q)) {
+	    n = node_queue_pop_front(&q);
 	    nd = nData(n);
 	    MARK(nd);
 	    POP(nd);
@@ -566,20 +566,22 @@ static void travBFS(Gpr_t * state, Expr_t* prog, comp_block * xprog)
 		    continue;
 		if (!evalEdge(state, prog, xprog, cure)) continue;
 		if (!ONSTACK(nd)) {
-		    queue_push(&q, cure->node);
+		    node_queue_push_back(&q, cure->node);
 		    PUSH(nd,cure);
 		}
 	    }
 	}
     }
     state->tvedge = 0;
-    queue_free(&q);
+    node_queue_free(&q);
 }
 
+DEFINE_LIST(edge_stack, Agedge_t *)
+
 static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns * fns)
 {
     Agnode_t *n;
-    gv_stack_t stk = {0};
+    edge_stack_t stk = {0};
     Agnode_t *curn;
     Agedge_t *cure;
     Agedge_t *entry;
@@ -625,7 +627,7 @@ static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns *
 			evalEdge(state, prog, xprog, cure);
 		} else {
 		    evalEdge(state, prog, xprog, cure);
-		    stack_push(&stk, entry);
+		    edge_stack_push_back(&stk, entry);
 		    state->tvedge = entry = cure;
 		    curn = cure->node;
 		    cure = 0;
@@ -640,7 +642,7 @@ static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns *
 		nd = nData(curn);
 		POP(nd);
 		cure = entry;
-		entry = stack_is_empty(&stk) ? NULL : stack_pop(&stk);
+		entry = edge_stack_is_empty(&stk) ? NULL : edge_stack_pop_back(&stk);
 		if (entry == &(seed.out))
 		    state->tvedge = 0;
 		else
@@ -653,7 +655,7 @@ static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns *
 	}
     }
     state->tvedge = 0;
-    stack_reset(&stk);
+    edge_stack_free(&stk);
 }
 
 static void travNodes(Gpr_t * state, Expr_t* prog, comp_block * xprog)
