@@ -10,15 +10,15 @@
 
 #include "config.h"
 #include <common/boxes.h>
-#include <cgraph/alloc.h>
 #include <cgraph/bitarray.h>
-#include <cgraph/prisize_t.h>
 #include <ortho/partition.h>
 #include <ortho/trap.h>
 #include <math.h>
 #include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <util/alloc.h>
+#include <util/prisize_t.h>
 
 #ifndef DEBUG
   #define DEBUG 0
