@@ -15,7 +15,6 @@
  */
 
 #include    <assert.h>
-#include    <cgraph/alloc.h>
 #include    <cgraph/list.h>
 #include    <cgraph/startswith.h>
 #include    <limits.h>
@@ -24,6 +23,7 @@
 #include    <pack/pack.h>
 #include    <stdbool.h>
 #include    <stddef.h>
+#include    <util/alloc.h>
 
 #define DFLT_SZ  18
 #define PARENT(n) ((Agraph_t*)ND_alg(n))
@@ -65,7 +65,7 @@ layout (Agraph_t* g, int depth)
     int nvs = 0;       /* no. of nodes in subclusters */
     Agnode_t*  n;
     Agraph_t*  subg;
-    point* pts;
+    pointf* pts;
     boxf bb, rootbb;
     pointf p;
     pack_info pinfo;
@@ -147,7 +147,7 @@ layout (Agraph_t* g, int depth)
 
     /* reposition children relative to GD_bb(g) */
     for (j = 0; j < total; j++) {
-	P2PF(pts[j],p);
+	p = pts[j];
 	bb = gs[j];
 	bb.LL.x += p.x;
 	bb.UR.x += p.x;
