@@ -16,8 +16,6 @@
 
 #include <math.h>
 #include <assert.h>
-#include <cgraph/alloc.h>
-#include <cgraph/prisize_t.h>
 #include <cgraph/sort.h>
 #include <cgraph/startswith.h>
 #include <common/render.h>
@@ -25,6 +23,8 @@
 #include <common/pointset.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <util/alloc.h>
+#include <util/prisize_t.h>
 #include <util/streq.h>
 
 #define C 100			/* Max. avg. polyomino size */
