@@ -15,9 +15,6 @@
 #include <math.h>
 #include <stdbool.h>
 #include <stdlib.h>
-#include <cgraph/alloc.h>
-#include <cgraph/exit.h>
-#include <cgraph/unused.h>
 #include <common/types.h>
 #include <common/globals.h>
 
@@ -27,6 +24,9 @@
 #include <sfdpgen/spring_electrical.h>
 #include <neatogen/call_tri.h>
 #include <sfdpgen/sfdp.h>
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/unused.h>
 
 #define node_degree(i) (ia[(i)+1] - ia[(i)])
 
