@@ -10,6 +10,7 @@
 
 #include "config.h"
 
+#include <assert.h>
 #include <stdarg.h>
 #include <stdbool.h>
 #include <stdlib.h>
@@ -20,15 +21,15 @@
 
 #include <gvc/gvplugin_render.h>
 #include <gvc/gvplugin_device.h>
-#include <cgraph/alloc.h>
 #include <cgraph/agxbuf.h>
 #include <cgraph/gv_ctype.h>
-#include <cgraph/prisize_t.h>
-#include <cgraph/unreachable.h>
 #include <common/utils.h>
 #include <gvc/gvc.h>
 #include <gvc/gvio.h>
+#include <util/alloc.h>
+#include <util/prisize_t.h>
 #include <util/streq.h>
+#include <util/unreachable.h>
 #include "core_loadimage_xdot.h"
 
 typedef enum {
@@ -74,6 +75,7 @@ typedef struct {
     attrsym_t *tl_draw;
     unsigned short version;
     char* version_s;
+    double yOff; ///< ymin + ymax
 } xdot_state_t;
 static xdot_state_t* xd;
 
@@ -101,7 +103,8 @@ static void xdot_fmt_num(agxbuf *buf, double v) {
 static void xdot_point(agxbuf *xb, pointf p)
 {
   xdot_fmt_num(xb, p.x);
-  xdot_fmt_num(xb, yDir(p.y));
+  assert(xd != NULL);
+  xdot_fmt_num(xb, yDir(p.y, xd->yOff));
 }
 
 static void xdot_num(agxbuf *xb, double v)
@@ -308,9 +311,11 @@ static unsigned short versionStr2Version(const char *str) {
  * and "t" (for tooltip) and "x" (for position). We use  those letters in 
  * our drawing spec (and also "<" and ">"), so if you  start generating 
  * output with them, it could break what we have. 
+ *
+ * @param yOff ymax - ymin
  */
 static void xdot_begin_graph(graph_t *g, bool s_arrows, bool e_arrows,
-                             format_type id) {
+                             format_type id, double yOff) {
     int i;
     unsigned short us;
     char* s;
@@ -370,6 +375,8 @@ static void xdot_begin_graph(graph_t *g, bool s_arrows, bool e_arrows,
 
     for (i = 0; i < NUMXBUFS; i++)
 	xbuf[i] = (agxbuf){0};
+
+    xd->yOff = yOff;
 }
 
 static void dot_begin_graph(GVJ_t *job)
@@ -392,8 +399,8 @@ static void dot_begin_graph(GVJ_t *job)
 	case FORMAT_XDOT14: {
 	    bool e_arrows; // graph has edges with end arrows
 	    bool s_arrows; // graph has edges with start arrows
-	    attach_attrs_and_arrows(g, &s_arrows, &e_arrows);
-	    xdot_begin_graph(g, s_arrows, e_arrows, job->render.id);
+	    const double yOff = attach_attrs_and_arrows(g, &s_arrows, &e_arrows);
+	    xdot_begin_graph(g, s_arrows, e_arrows, job->render.id, yOff);
 	    break;
 	}
 	default:
