@@ -22,14 +22,14 @@
 
 #include <gvc/gvplugin_render.h>
 #include <gvc/gvplugin_device.h>
-#include <cgraph/alloc.h>
 #include <cgraph/startswith.h>
-#include <cgraph/unreachable.h>
 #include <common/utils.h>
 #include <gvc/gvc.h>
 #include <gvc/gvio.h>
 #include <gvc/gvcint.h>
+#include <util/alloc.h>
 #include <util/streq.h>
+#include <util/unreachable.h>
 
 typedef enum {
 	FORMAT_JSON,
