@@ -15,12 +15,6 @@
 #include <string>
 #include <LASi.h>
 
-// Confusingly, Freetype (included transitively by LASi), ship their Autotools
-// config.h. As a result, we get macros like `HAVE_FCNTL_H` injected from their
-// headers, overriding ours. Suppress this and force ours into scope.
-#ifdef HAVE_FCNTL_H
-#undef HAVE_FCNTL_H
-#endif
 #include "config.h"
 
 #include <gvc/gvplugin_render.h>
@@ -28,10 +22,10 @@
 #include <gvc/gvio.h>
 #include <gvc/gvcint.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/prisize_t.h>
-#include <cgraph/unreachable.h>
 #include <common/const.h>
 #include <common/utils.h>
+#include <util/prisize_t.h>
+#include <util/unreachable.h>
 #include "../core/ps.h"
 
 using namespace LASi;
