@@ -8,8 +8,9 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <cgraph/unreachable.h>
 #include <stdint.h>
+#include <util/alloc.h>
+#include <util/unreachable.h>
 #include "tcldot.h"
 
 // Agiddisc functions
@@ -17,7 +18,7 @@ static void *myiddisc_open(Agraph_t *g, Agdisc_t *disc) {
     ictx_t *ictx = (ictx_t *)disc;
     gctx_t *gctx;
 
-    gctx = malloc(sizeof(gctx_t));
+    gctx = gv_alloc(sizeof(gctx_t));
     gctx->g = g;
     gctx->ictx = ictx;
     return gctx;
@@ -91,11 +92,7 @@ static void myiddisc_idregister(void *state, int objtype, void *obj) {
         case AGOUTEDGE: proc=edgecmd; break;
         default: UNREACHABLE();
     }
-#ifndef TCLOBJ
     Tcl_CreateCommand(interp, obj2cmd(obj), proc, (ClientData) gctx, (Tcl_CmdDeleteProc *) NULL);
-#else
-    Tcl_CreateObjCommand(interp, obj2cmd(obj), proc, (ClientData) gctx, (Tcl_CmdDeleteProc *) NULL);
-#endif           
 }
 Agiddisc_t myiddisc = {
     myiddisc_open,
