@@ -9,20 +9,17 @@
  *************************************************************************/
 
 
-/* avoid compiler warnings with template changes in Tcl8.4 */
-/*    specifically just the change to Tcl_CmdProc */
-#define USE_NON_CONST
 #include <tcl.h>
+#ifdef EXTERN
+// tcl.h defines `EXTERN` which interferes with the `EXTERN` in globals.h
+#undef EXTERN
+#endif
 #include <common/render.h>
 #include <gvc/gvc.h>
 #include <gvc/gvio.h>
 #include "tclhandle.h"
 #include "../../plugin/core/tcl_context.h"
 
-#ifndef CONST84
-#define CONST84
-#endif
-
 /*
  * ictx - one per tcl interpreter, may support multiple graph namespaces
  */
@@ -48,35 +45,17 @@ extern void *GDHandleTable;
 extern int Gdtclft_Init(Tcl_Interp *);
 #endif
 
-extern int graphcmd(ClientData clientData, Tcl_Interp * interp,
-#ifndef TCLOBJ
-		    int argc, char *argv[]
-#else
-		    int argc, Tcl_Obj * CONST objv[]
-#endif
-    );
-extern int nodecmd(ClientData clientData, Tcl_Interp * interp,
-#ifndef TCLOBJ
-		    int argc, char *argv[]
-#else
-		    int argc, Tcl_Obj * CONST objv[]
-#endif
-    );
-extern int edgecmd(ClientData clientData, Tcl_Interp * interp,
-#ifndef TCLOBJ
-		    int argc, char *argv[]
-#else
-		    int argc, Tcl_Obj * CONST objv[]
-#endif
-    );
+extern int graphcmd(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[]);
+extern int nodecmd(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[]);
+extern int edgecmd(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[]);
 
 extern int myiodisc_afread(void* channel, char *ubuf, int n);
 extern int myiodisc_memiofread(void *chan, char *buf, int bufsize);
 extern Agiddisc_t myiddisc;
 extern Agraph_t *agread_usergets (ictx_t *ictx, FILE * fp, int (*usergets)(void *chan, char *buf, int bufsize));
-extern Agraph_t *cmd2g(char *cmd);
-extern Agnode_t *cmd2n(char *cmd);
-extern Agedge_t *cmd2e(char *cmd);
+extern Agraph_t *cmd2g(const char *cmd);
+extern Agnode_t *cmd2n(const char *cmd);
+extern Agedge_t *cmd2e(const char *cmd);
 extern char *obj2cmd(void *obj);
 extern void deleteEdge(gctx_t *gctx, Agraph_t * g, Agedge_t * e);
 extern void deleteNode(gctx_t *gctx, Agraph_t * g, Agnode_t * n);
@@ -92,4 +71,9 @@ extern void setnodeattributes(Agraph_t * g, Agnode_t * n, char *argv[], int argc
 extern size_t Tcldot_string_writer(GVJ_t *job, const char *s, size_t len);
 extern size_t Tcldot_channel_writer(GVJ_t *job, const char *s, size_t len);
 
-extern void tcldot_layout(GVC_t *gvc, Agraph_t * g, char *engine);
+extern void tcldot_layout(GVC_t *gvc, Agraph_t * g, const char *engine);
+
+/// duplicate the strings pointed to by `argv` as non-const strings
+char **tcldot_argv_dup(int argc, const char *argv[]);
+/// free the strings pointed to by `argv`
+void tcldot_argv_free(int argc, char *argv[]);
