@@ -17,10 +17,6 @@
 
 #include "config.h"
 
-/* avoid compiler warnings with template changes in Tcl8.4 */
-/*    specifically just the change to Tcl_CmdProc */
-#define USE_NON_CONST
-
 #include                <sys/types.h>
 #include                <stdbool.h>
 #include                <stdint.h>
@@ -30,7 +26,6 @@
 #include <inttypes.h>
 #include <assert.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/list.h>
 #include <limits.h>
 #include "makecw.h"
@@ -41,10 +36,7 @@
 #include "Plegal_arrangement.h"
 #include <tcl.h>
 #include "tclhandle.h"
-
-#ifndef CONST84
-#define CONST84
-#endif
+#include <util/alloc.h>
 
 #if ((TCL_MAJOR_VERSION == 8) && (TCL_MINOR_VERSION >= 6)) || ( TCL_MAJOR_VERSION > 8)
 #else
@@ -105,45 +97,41 @@ static int vc_refresh(vgpane_t * vgp)
     return vgp->vc != NULL;
 }
 
-static void dgsprintxy(Tcl_DString * result, int npts, point p[])
-{
+static void dgsprintxy(agxbuf *result, int npts, const point p[]) {
     int i;
-    char buf[20];
 
-    if (npts != 1)
-	Tcl_DStringStartSublist(result);
-    for (i = 0; i < npts; i++) {
-	snprintf(buf, sizeof(buf), "%g", p[i].x);
-	Tcl_DStringAppendElement(result, buf);
-	snprintf(buf, sizeof(buf), "%g", p[i].y);
-	Tcl_DStringAppendElement(result, buf);
+    assert(npts > 1);
+    if (agxblen(result) > 0) {
+	agxbputc(result, ' ');
     }
-    if (npts != 1)
-	Tcl_DStringEndSublist(result);
+    agxbputc(result, '{');
+    const char *separator = "";
+    for (i = 0; i < npts; i++) {
+	agxbprint(result, "%s%g %g", separator, p[i].x, p[i].y);
+	separator = " ";
+    }
+    agxbputc(result, '}');
 }
 
-static void expandPercentsEval(Tcl_Interp * interp,	/* interpreter context */
-			       char *before,	/* Command with percent expressions */
-			       char *r,	/* vgpaneHandle string to substitute for "%r" */
-			       int npts,	/* number of coordinates */
-			       point * ppos	/* Cordinates to substitute for %t */
-    )
-{
-    char *string;
-    Tcl_DString scripts;
+/// @param interp Interpreter context
+/// @param before Command with percent expressions
+/// @param vgcanvasHandle Index to use in "%r" substitution
+/// @param npts Number of coordinates
+/// @param ppos Coordinates to substitute for %t
+static void expandPercentsEval(Tcl_Interp *interp, char *before,
+                               uint64_t vgcanvasHandle, int npts,
+                               const point *ppos) {
+    agxbuf scripts = {0};
 
-    Tcl_DStringInit(&scripts);
     while (1) {
 	/*
 	 * Find everything up to the next % character and append it to the
 	 * result string.
 	 */
 
-	for (string = before; *string != '\0' && *string != '%'; string++) {
-	    /* Empty loop body. */
-	}
-	if (string != before) {
-	    Tcl_DStringAppend(&scripts, before, string - before);
+	char *string = strchr(before, '%');
+	if (string != NULL) {
+	    agxbput_n(&scripts, before, (size_t)(string - before));
 	    before = string;
 	}
 	if (*before == 0) {
@@ -155,35 +143,34 @@ static void expandPercentsEval(Tcl_Interp * interp,	/* interpreter context */
 
 	switch (before[1]) {
 	case 'r':
-	    Tcl_DStringAppend(&scripts, r, strlen(r));	/* vgcanvasHandle */
+	    agxbprint(&scripts, "vgpane%" PRIu64, vgcanvasHandle);
 	    break;
 	case 't':
 	    dgsprintxy(&scripts, npts, ppos);
 	    break;
 	default:
-	    Tcl_DStringAppend(&scripts, before + 1, 1);
+	    agxbputc(&scripts, before[1]);
 	    break;
 	}
 	before += 2;
     }
-    if (Tcl_GlobalEval(interp, Tcl_DStringValue(&scripts)) != TCL_OK)
+    const char *script_value = agxbuse(&scripts);
+    if (Tcl_GlobalEval(interp, script_value) != TCL_OK)
 	fprintf(stderr, "%s while in binding: %s\n\n",
-		Tcl_GetStringResult(interp), Tcl_DStringValue(&scripts));
-    Tcl_DStringFree(&scripts);
+		Tcl_GetStringResult(interp), script_value);
+    agxbfree(&scripts);
 }
 
-static void triangle_callback(void *vgparg, point pqr[])
-{
-    char vbuf[20];
+static void triangle_callback(void *vgparg, const point pqr[]) {
     vgpane_t *vgp;
 
     vgp = vgparg;
 
     if (vgp->triangle_cmd) {
-	snprintf(vbuf, sizeof(vbuf), "vgpane%" PRIu64,
+	const uint64_t vgcanvasHandle =
 		((uint64_t)((uintptr_t)vgp - (uintptr_t)vgpaneTable->bodyPtr))
-				 / vgpaneTable->entrySize);
-	expandPercentsEval(vgp->interp, vgp->triangle_cmd, vbuf, 3, pqr);
+				 / vgpaneTable->entrySize;
+	expandPercentsEval(vgp->interp, vgp->triangle_cmd, vgcanvasHandle, 3, pqr);
     }
 }
 
@@ -232,7 +219,7 @@ static char *buildBindings(char *s1, const char *s2)
 
 
 /* convert x and y string args to point */
-static int scanpoint(Tcl_Interp * interp, char *argv[], point * p)
+static int scanpoint(Tcl_Interp * interp, const char *argv[], point * p)
 {
     if (sscanf(argv[0], "%lg", &(p->x)) != 1) {
 	Tcl_AppendResult(interp, "invalid x coordinate: \"", argv[0], "\"", NULL);
@@ -306,7 +293,7 @@ static bool remove_poly(vgpane_t *vgp, int id) {
 }
 
 static int
-insert_poly(Tcl_Interp * interp, vgpane_t * vgp, int id, char *vargv[],
+insert_poly(Tcl_Interp * interp, vgpane_t * vgp, int id, const char *vargv[],
 	    int vargc)
 {
     poly *np;
@@ -372,12 +359,13 @@ static void appendpoint(Tcl_Interp * interp, point p)
 /* process vgpane methods */
 static int
 vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
-	  char *argv[])
+	  const char *argv[])
 {
     (void)clientData;
 
     int vargc, result;
-    char *s, **vargv, vbuf[30];
+    char *s, vbuf[30];
+    const char **vargv;
     vgpane_t *vgp, **vgpp;
     point p, q, *ps;
     double alpha, gain;
@@ -424,7 +412,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (argc == 4) {
 	    result =
 		Tcl_SplitList(interp, argv[3], &vargc,
-			      (CONST84 char ***) &vargv);
+			      (const char ***) &vargv);
 	    if (result != TCL_OK) {
 		return result;
 	    }
@@ -473,7 +461,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (argc == 3) {
 	    result =
 		Tcl_SplitList(interp, argv[2], &vargc,
-			      (CONST84 char ***) &vargv);
+			      (const char ***) &vargv);
 	    if (result != TCL_OK) {
 		return result;
 	    }
@@ -506,7 +494,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (argc == 3) {
 	    result =
 		Tcl_SplitList(interp, argv[2], &vargc,
-			      (CONST84 char ***) &vargv);
+			      (const char ***) &vargv);
 	    if (result != TCL_OK) {
 		return result;
 	    }
@@ -550,7 +538,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (argc == 3) {
 	    result =
 		Tcl_SplitList(interp, argv[2], &vargc,
-			      (CONST84 char ***) &vargv);
+			      (const char ***) &vargv);
 	    if (result != TCL_OK) {
 		return result;
 	    }
@@ -615,7 +603,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (argc == 3) {
 	    result =
 		Tcl_SplitList(interp, argv[2], &vargc,
-			      (CONST84 char ***) &vargv);
+			      (const char ***) &vargv);
 	    if (result != TCL_OK) {
 		return result;
 	    }
@@ -813,7 +801,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 }
 
 static int
-vgpane(ClientData clientData, Tcl_Interp * interp, int argc, char *argv[])
+vgpane(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[])
 {
     (void)clientData;
     (void)argc;
@@ -862,7 +850,7 @@ int Tclpathplan_Init(Tcl_Interp * interp)
 
     Tcl_CreateCommand(interp, "vgpane", vgpane, (ClientData)NULL, NULL);
 
-    vgpaneTable = tclhandleInit("vgpane", sizeof(vgpane_t), 10);
+    vgpaneTable = tclhandleInit(sizeof(vgpane_t), 10);
 
     return TCL_OK;
 }
