@@ -287,8 +287,7 @@ TESTS: List[Case] = [
     Case("nestedclust", Path("nestedclust"), "dot", "gv", []),
     Case("rd_rules", Path("rd_rules.gv"), "dot", "png", []),
     Case("sq_rules", Path("sq_rules.gv"), "dot", "png", []),
-    # FIXME: Re-enable when https://gitlab.com/graphviz/graphviz/-/issues/1690 is fixed
-    # Case("fdp_clus", Path("fdp.gv"), "fdp", "png", []),
+    Case("fdp_clus", Path("fdp.gv"), "fdp", "png", []),
     Case("japanese", Path("japanese.gv"), "dot", "png", []),
     Case("russian", Path("russian.gv"), "dot", "png", []),
     Case("AvantGarde", Path("AvantGarde.gv"), "dot", "png", []),
@@ -321,18 +320,6 @@ def doDiff(OUTFILE, testname, fmt):
     FILE1 = OUTDIR / OUTFILE
     FILE2 = REFDIR / OUTFILE
     F = fmt.split(":")[0]
-    # FIXME: Remove when https://gitlab.com/graphviz/graphviz/-/issues/1789 is
-    # fixed
-    if (
-        platform.system() == "Windows"
-        and F in ["ps", "gv"]
-        and testname in ["clusters", "compound", "rootlabel"]
-    ):
-        pytest.skip(
-            f"Warning: Skipping {F} output comparison for test "
-            f"{testname}: format {fmt} because the order of "
-            "clusters in gv or ps output is not stable on Windows (#1789)"
-        )
     if F in ["ps", "ps2"]:
         with open(FILE1, "rt", encoding="latin-1") as src:
             dst1 = io.StringIO()
@@ -360,13 +347,6 @@ def doDiff(OUTFILE, testname, fmt):
             b = re.sub(r"^<!--.*-->$", "", f.read(), flags=re.MULTILINE)
         returncode = 0 if a.strip() == b.strip() else -1
     elif F == "png":
-        # FIXME: remove when https://gitlab.com/graphviz/graphviz/-/issues/1788 is fixed
-        if os.environ.get("build_system") == "cmake" and platform.system() == "Windows":
-            pytest.skip(
-                f"Warning: Skipping PNG image comparison for test {testname}:"
-                f" format: {fmt} because CMake builds on Windows "
-                "do not contain the diffimg utility (#1788)"
-            )
         OUTHTML.mkdir(exist_ok=True)
         returncode = subprocess.call(
             ["diffimg", FILE1, FILE2, OUTHTML / f"dif_{OUTFILE}"],
@@ -421,22 +401,14 @@ def test_graph(name: str, input: Path, algorithm: str, format: str, flags: List[
     """
     Run a single test.
     """
-    if input.suffix == ".gv":
-        INFILE = GRAPHDIR / input
-    else:
+    if input.suffix != ".gv":
         pytest.skip(f"Unknown graph spec, test {name} - ignoring")
+    INFILE = GRAPHDIR / input
 
     OUTFILE = genOutname(name, algorithm, format, flags)
     OUTDIR.mkdir(exist_ok=True)
     OUTPATH = OUTDIR / OUTFILE
     testcmd = ["dot", f"-K{algorithm}", f"-T{format}"] + flags + ["-o", OUTPATH, INFILE]
-    # FIXME: Remove when https://gitlab.com/graphviz/graphviz/-/issues/1786 is
-    # fixed
-    if os.environ.get("build_system") == "cmake" and format == "png:gd":
-        pytest.skip(
-            f"Skipping test {name}: format {format} because "
-            "CMake builds does not support format png:gd (#1786)"
-        )
     # FIXME: Remove when https://gitlab.com/graphviz/graphviz/-/issues/1269 is
     # fixed
     if (
