@@ -72,9 +72,6 @@
 /* Define if the GD library supports XPM */
 /* #undef HAVE_GD_XPM */
 
-/* Define if you have the glade library */
-#define HAVE_GLADE 1
-
 /* Define if you have the gs library */
 /* #undef HAVE_GS */
 
@@ -114,9 +111,6 @@
 /* Define to 1 if you have the `pango_fc_font_lock_face' function. */
 /* #undef HAVE_PANGO_FC_FONT_LOCK_FACE */
 
-/* Define to 1 if you have the `pango_fc_font_unlock_face' function. */
-/* #undef HAVE_PANGO_FC_FONT_UNLOCK_FACE */
-
 /* Define if you have the rsvg library */
 #define HAVE_RSVG 1
 
@@ -156,12 +150,6 @@
 /* Define if you have the tcl library */
 /* #undef HAVE_TCL */
 
-/* Define to 1 if you have the <tkInt.h> header file. */
-/* #undef HAVE_TKINT_H */
-
-/* Define to 1 if you have the <tk.h> header file. */
-/* #undef HAVE_TK_H */
-
 /* Define if triangle.[ch] are available. */
 /* #undef HAVE_TRIANGLE */
 
@@ -200,10 +188,6 @@
 /* Define if you want CGRAPH */
 #define WITH_CGRAPH 1
 
-/* Define to 1 if `lex' declares `yytext' as a `char *' by default, not a
-   `char[]'. */
-/* #undef YYTEXT_POINTER */
-
 /* Define to `int' if <sys/types.h> does not define. */
 /* #undef pid_t */
 
